@@ -259,12 +259,13 @@ macro_rules! impl_object_methods {
   ($js_value:ident) => {
     impl $js_value {
       #[inline]
-      pub fn set_property<V>(&mut self, key: JsString, value: V) -> Result<()>
+      pub fn set_property<V, K>(&mut self, key: K, value: V) -> Result<()>
       where
         V: NapiRaw,
+        K: NapiRaw,
       {
         check_status!(unsafe {
-          sys::napi_set_property(self.0.env, self.0.value, key.0.value, value.raw())
+          sys::napi_set_property(self.0.env, self.0.value, key.raw(), value.raw())
         })
       }
 
